LOdoo
=====


CLI to manage locally-installed Odoo.

This script is used by [odoo-helper-scripts](https://github.com/katyukha/odoo-helper-scripts)
and [OdooD](https://github.com/katyukha/odood)
to manage locally-installed odoo.

For example, it provides CLI commands, like:

- addons-uninstall
- addons-update-list
- db-backup
- db-copy
- db-create
- db-drop
- db-dump-manifest
- db-exists
- db-list
- db-rename
- db-restore
- odoo-recompute
- run-py-script
- tr-check-translation-rate
- tr-generate-pot-file


Supported odoo versions
-----------------------

- Odoo 19.0
- Odoo 18.0
- Odoo 17.0
- Odoo 16.0
- Odoo 15.0
- Odoo 14.0
- Odoo 13.0
- Odoo 12.0
- Odoo 11.0
- Odoo 10.0
- Odoo 9.0
- Odoo 8.0
- Odoo 7.0 (Limited support)

